@@ -3,7 +3,9 @@ context("lio_platforms")
 test_that("lio_platforms works", {
   skip_on_cran()
   
-  a <- lio_platforms()
+  vcr::use_cassette("lio_platforms", {
+    a <- lio_platforms()
+  })
   
   expect_is(a, "list")
   expect_named(a, c('name', 'project_count', 'homepage', 
